# Nasheq E.R.P. Standardized A.P.I.s python integrations

## Quick Guide
Below are the steps on how to get the web app up and running

1.	Clone it:
```bash
    git clone https://dans0l@bitbucket.org/dans0l/erp_sync.git
```
2.	Cd into it:
```bash
    cd erp_sync
```
3.	Create a venv
```bash
    python3 -m venv venv
```
4.	Activate venv:
```bash
    Mac/Linux: source venv/bin/activate
    Windows: venv\Scripts\activate
```
5.	Install the requirements
```bash
    pip install -r requirements.txt
```
6.	Start Coding
7.	Look at the sample docs.ipynb file on getting started